pub struct CancelledNotification {
pub params: CancelledNotificationParams,
/* private fields */
}Expand description
This notification is sent by the client to indicate that it is cancelling a request it previously issued. On stdio, the server also sends this notification, solely to terminate a {@link SubscriptionsListenRequestsubscriptions/listen} stream: it references the ID of the subscriptions/listen request that opened the stream. Servers MUST NOT use this notification to cancel any other request. The request SHOULD still be in-flight, but due to communication latency, it is always possible that this notification MAY arrive after the request has already finished. This notification indicates that the result will be unused, so any associated processing SHOULD cease.
JSON schema
{
"description": "This notification is sent by the client to indicate that it is cancelling a request it previously issued.\n\nOn stdio, the server also sends this notification, solely to terminate a {@link SubscriptionsListenRequestsubscriptions/listen} stream: it references the ID of the subscriptions/listen request that opened the stream. Servers MUST NOT use this notification to cancel any other request.\n\nThe request SHOULD still be in-flight, but due to communication latency, it is always possible that this notification MAY arrive after the request has already finished.\n\nThis notification indicates that the result will be unused, so any associated processing SHOULD cease.",
"type": "object",
"required": [
"jsonrpc",
"method",
"params"
],
"properties": {
"jsonrpc": {
"type": "string",
"const": "2.0"
},
"method": {
"type": "string",
"const": "notifications/cancelled"
},
"params": {
"$ref": "#/$defs/CancelledNotificationParams"
}
}
}Fields
params: CancelledNotificationParamsImplementations
Sourceimpl CancelledNotification
impl CancelledNotification
pub fn new(params: CancelledNotificationParams) -> CancelledNotification
pub fn jsonrpc(&self) -> &String
pub fn method(&self) -> &String
Sourcepub fn method_value() -> &'static str
pub fn method_value() -> &'static str
returns “notifications/cancelled”
pub fn method_name() -> &'static str
👎Deprecated since 0.8.0:
Use method_value() instead.