pub struct GetPromptResult {
pub description: Option<String>,
pub messages: Vec<PromptMessage>,
pub meta: Option<ResultMetaObject>,
pub result_type: String,
}Expand description
The result returned by the server for a {@link GetPromptRequestprompts/get} request.
JSON schema
{
"description": "The result returned by the server for a {@link GetPromptRequestprompts/get} request.",
"type": "object",
"required": [
"messages",
"resultType"
],
"properties": {
"_meta": {
"$ref": "#/$defs/ResultMetaObject"
},
"description": {
"description": "An optional description for the prompt.",
"type": "string"
},
"messages": {
"type": "array",
"items": {
"$ref": "#/$defs/PromptMessage"
}
},
"resultType": {
"description": "Indicates the type of the result, which allows the client to determine\nhow to parse the result object.\n\nServers implementing this protocol version MUST include this field.\nFor backward compatibility, when a client receives a result from a\nserver implementing an earlier protocol version (which does not include\nresultType), the client MUST treat the absent field as \"complete\".",
"type": "string"
}
}
}Fields
description: Option<String>An optional description for the prompt.
messages: Vec<PromptMessage>meta: Option<ResultMetaObject>result_type: StringIndicates the type of the result, which allows the client to determine how to parse the result object. Servers implementing this protocol version MUST include this field. For backward compatibility, when a client receives a result from a server implementing an earlier protocol version (which does not include resultType), the client MUST treat the absent field as “complete”.