pub struct RpcError {
pub code: i64,
pub data: Option<Value>,
pub message: String,
}Expand description
RpcError
JSON schema
{
"type": "object",
"required": [
"code",
"message"
],
"properties": {
"code": {
"description": "The error type that occurred.",
"type": "integer"
},
"data": {
"description": "Additional information about the error. The value of this member is defined by the sender (e.g. detailed error information, nested errors etc.)."
},
"message": {
"description": "A short description of the error. The message SHOULD be limited to a concise single sentence.",
"type": "string"
}
}
}Fields
code: i64The error type that occurred.
data: Option<Value>Additional information about the error. The value of this member is defined by the sender (e.g. detailed error information, nested errors etc.).
message: StringA short description of the error. The message SHOULD be limited to a concise single sentence.
Implementations
Sourceimpl RpcError
impl RpcError
pub fn new( error_code: RpcErrorCodes, message: String, data: Option<Value>, ) -> RpcError
pub fn method_not_found() -> RpcError
pub fn invalid_params() -> RpcError
pub fn invalid_request() -> RpcError
pub fn internal_error() -> RpcError
pub fn parse_error() -> RpcError
pub fn with_message<T>(self, message: T) -> RpcError
pub fn with_data(self, data: Option<Value>) -> RpcError