pub struct UnsubscribeMeta {
pub progress_token: Option<ProgressToken>,
pub extra: Option<Map<String, Value>>,
}Expand description
See General fields: _meta for notes on _meta usage.
JSON schema
{
"description": "See [General fields: _meta](https://modelcontextprotocol.io/specification/2025-11-25/basic/index#meta) for notes on _meta usage.",
"type": "object",
"properties": {
"progressToken": {
"description": "If specified, the caller is requesting out-of-band progress notifications for this request (as represented by notifications/progress). The value of this parameter is an opaque token that will be attached to any subsequent notifications. The receiver is not obligated to provide these notifications.",
"$ref": "#/$defs/ProgressToken"
}
},
"additionalProperties": {}
}Fields
progress_token: Option<ProgressToken>If specified, the caller is requesting out-of-band progress notifications for this request (as represented by notifications/progress). The value of this parameter is an opaque token that will be attached to any subsequent notifications. The receiver is not obligated to provide these notifications.
extra: Option<Map<String, Value>>Trait Implementations
Sourceimpl Clone for UnsubscribeMeta
impl Clone for UnsubscribeMeta
Sourcefn clone(&self) -> UnsubscribeMeta
fn clone(&self) -> UnsubscribeMeta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnsubscribeMeta
impl Debug for UnsubscribeMeta
Sourceimpl Default for UnsubscribeMeta
impl Default for UnsubscribeMeta
Sourcefn default() -> UnsubscribeMeta
fn default() -> UnsubscribeMeta
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UnsubscribeMeta
impl<'de> Deserialize<'de> for UnsubscribeMeta
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<UnsubscribeMeta, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<UnsubscribeMeta, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for UnsubscribeMeta
impl Serialize for UnsubscribeMeta
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more