pub struct RpcError {
pub code: i64,
pub data: Option<Value>,
pub message: String,
}Expand description
RpcError
JSON schema
{
"type": "object",
"required": [
"code",
"message"
],
"properties": {
"code": {
"description": "The error type that occurred.",
"type": "integer"
},
"data": {
"description": "Additional information about the error. The value of this member is defined by the sender (e.g. detailed error information, nested errors etc.)."
},
"message": {
"description": "A short description of the error. The message SHOULD be limited to a concise single sentence.",
"type": "string"
}
}
}Fields
code: i64The error type that occurred.
data: Option<Value>Additional information about the error. The value of this member is defined by the sender (e.g. detailed error information, nested errors etc.).
message: StringA short description of the error. The message SHOULD be limited to a concise single sentence.
Implementations
Sourceimpl RpcError
impl RpcError
Sourcepub fn new(
error_code: RpcErrorCodes,
message: String,
data: Option<Value>,
) -> RpcError
pub fn new( error_code: RpcErrorCodes, message: String, data: Option<Value>, ) -> RpcError
Constructs a new RpcError with the provided arguments.
Arguments
error_code- The JSON-RPC error code.message- A descriptive error message.data- Optional additional data.
Example
use serde_json::json;
use rust_mcp_schema::{RpcError, schema_utils::RpcErrorCodes};
let error = RpcError::new(RpcErrorCodes::INVALID_PARAMS, "Invalid params!".to_string(), Some(json!({"details": "Missing method field"})));
assert_eq!(error.code, -32602);
assert_eq!(error.message, "Invalid params!".to_string());Sourcepub fn method_not_found() -> RpcError
pub fn method_not_found() -> RpcError
Creates a new RpcError for “Method not found”.
Example
use rust_mcp_schema::RpcError;
let error = RpcError::method_not_found();
assert_eq!(error.code, -32601);
assert_eq!(error.message, "Method not found");Sourcepub fn url_elicit_required(
elicit_url_params: Vec<ElicitRequestUrlParams>,
) -> RpcError
pub fn url_elicit_required( elicit_url_params: Vec<ElicitRequestUrlParams>, ) -> RpcError
Creates a new RpcError indicating that a URL elicitation failed
and was required for the operation to continue.
The resulting error uses the -32042 value as introduced in mcp protocol 2025-11-25
The result json matches a UrlElicitError and the data value could be deserialized into UrlElicitErrorData
Sourcepub fn invalid_params() -> RpcError
pub fn invalid_params() -> RpcError
Creates a new RpcError for “Invalid parameters”.
Example
use rust_mcp_schema::RpcError;
let error = RpcError::invalid_params();
assert_eq!(error.code, -32602);Sourcepub fn invalid_request() -> RpcError
pub fn invalid_request() -> RpcError
Creates a new RpcError for “Invalid request”.
Example
use rust_mcp_schema::RpcError;
let error = RpcError::invalid_request();
assert_eq!(error.code, -32600);Sourcepub fn internal_error() -> RpcError
pub fn internal_error() -> RpcError
Creates a new RpcError for “Internal error”.
Example
use rust_mcp_schema::RpcError;
let error = RpcError::internal_error();
assert_eq!(error.code, -32603);Sourcepub fn parse_error() -> RpcError
pub fn parse_error() -> RpcError
Creates a new RpcError for “Parse error”.
Example
use rust_mcp_schema::RpcError;
let error = RpcError::parse_error();
assert_eq!(error.code, -32700);Sourcepub fn with_message<T>(self, message: T) -> RpcError
pub fn with_message<T>(self, message: T) -> RpcError
Sets a custom error message.
Example
use rust_mcp_schema::RpcError;
let error = RpcError::invalid_request().with_message("Request format is invalid".to_string());
assert_eq!(error.message, "Request format is invalid".to_string());Trait Implementations
Sourceimpl<'de> Deserialize<'de> for RpcError
impl<'de> Deserialize<'de> for RpcError
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RpcError, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RpcError, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl Error for RpcError
impl Error for RpcError
Sourcefn description(&self) -> &str
fn description(&self) -> &str
use the Display impl or to_string()
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Sourceimpl From<CallToolError> for RpcError
Converts a CallToolError into a RpcError.
impl From<CallToolError> for RpcError
Converts a CallToolError into a RpcError.
The conversion creates an internal error variant of RpcError
and attaches the string representation of the original CallToolError as a message.
Sourcefn from(value: CallToolError) -> RpcError
fn from(value: CallToolError) -> RpcError
Sourceimpl From<RpcError> for McpSdkError
impl From<RpcError> for McpSdkError
Sourceimpl From<RpcError> for MessageFromClient
impl From<RpcError> for MessageFromClient
Sourcefn from(value: RpcError) -> MessageFromClient
fn from(value: RpcError) -> MessageFromClient
Sourceimpl From<RpcError> for MessageFromServer
impl From<RpcError> for MessageFromServer
Sourcefn from(value: RpcError) -> MessageFromServer
fn from(value: RpcError) -> MessageFromServer
Sourceimpl From<RpcError> for TransportError
impl From<RpcError> for TransportError
Sourcefn from(source: RpcError) -> TransportError
fn from(source: RpcError) -> TransportError
Sourceimpl Serialize for RpcError
impl Serialize for RpcError
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,